FlickControllerState class

Inheritance
Mixed-in types

Constructors

FlickControllerState(bool useCache, GlobalKey<State<StatefulWidget>> viewKey, GlobalKey<State<StatefulWidget>>? boundKey, Offset? constraintsMin, Offset? constraintsMax, Offset? flexibilityMin, Offset? flexibilityMax, double sensitivity, MoveCallback? onMove, DragCallback? onDragStart, DragCallback? onDragUpdate, DragCallback? onDragEnd, FlickCallback? onFlick)

Properties

animation ↔ Animation<Offset>
getter/setter pair
animationController ↔ AnimationController
The AnimationController used to move the view during flicking.
getter/setter pair
boundHeight ↔ double
getter/setter pair
boundIsSet → bool
no setter
boundKey → GlobalKey<State<StatefulWidget>>?
final
boundOrigin ↔ Offset?
getter/setter pair
boundRenderBox ↔ RenderBox?
getter/setter pair
boundWidth ↔ double
getter/setter pair
canMove ↔ bool
getter/setter pair
constraintsMax ↔ Offset?
getter/setter pair
constraintsMin ↔ Offset?
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
delta ↔ Offset
getter/setter pair
deltaNotifier → ValueNotifier<Offset>
final
flexibilityMax → Offset?
final
flexibilityMin → Offset?
final
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
normalisedConstraintsMax ↔ Offset
getter/setter pair
normalisedConstraintsMin ↔ Offset
getter/setter pair
onDragEnd → DragCallback?
final
onDragStart → DragCallback?
final
onDragUpdate → DragCallback?
final
onFlick → FlickCallback?
final
onMove → FlickCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensitivity → double
final
uiChild ↔ Widget?
getter/setter pair
useCache → bool
final
viewHeight ↔ double
getter/setter pair
viewIsSet → bool
no setter
viewKey → GlobalKey<State<StatefulWidget>>
final
viewOrigin ↔ Offset?
getter/setter pair
viewRenderBox ↔ RenderBox?
getter/setter pair
viewWidth ↔ double
getter/setter pair
widget → FlickController
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
animationListener() → void
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
checkBoundOrigin() → void
checkViewAndBound() → void
checkViewOrigin() → void
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant FlickController oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
endDrag(dynamic dragEndDetails) → void
flick(dynamic dragEndDetails) → Future
getFlickTarget(dynamic dragEndDetails) → Offset
initState() → void
Called when this object is inserted into the tree.
override
move(Offset flickTarget) → Future
normaliseConstraints() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
reset() → void
setBound() → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setView() → void
shouldFlick(dynamic dragEndDetails, double treshold) → bool?
Use this function to determine if the view should flick or not.
softReset(Offset _constraintsMin, Offset _constraintsMax) → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
wrapper() → Widget

Operators

operator ==(Object other) → bool
The equality operator.
inherited